@@ -12,11 +12,11 @@ except ImportError:
     argparse = None
 
 
-__version__ = '0.3.1'
+__version__ = '0.5'
 __author__ = 'Hideo Hattroi <hhatto.jp@gmail.com>'
 __license__ = 'NewBSDLicense'
 
-__all__ = ["main", "ZshCompletionGenerator", "HelpParser"]
+__all__ = ["main", "CompletionGenerator", "HelpParser"]
 
 USAGE_DOCS = """\
 usage: genzshcomp FILE
@@ -63,9 +63,9 @@ def _escape_strings(strings):
     return "".join(ret)
 
 
-class ZshCompletionGenerator(object):
+class CompletionGenerator(object):
 
-    """Generator of Zsh Completion Function"""
+    """Generator of (Z|Ba)sh Completion Function"""
 
     def __init__(self, commandname=None, parser=None, parser_type=None,
                  output_format=None):
@@ -124,6 +124,34 @@ class ZshCompletionGenerator(object):
                 ret.append(tmp)
         return "\n".join(ret)
 
+    def _get_bash_format(self):
+        """return to string of bash completion function format."""
+        ret = []
+        ret.append("#!bash\n#")
+        ret.append("# this is bash completion function file for %s." % self.commandname)
+        ret.append("# generated by genzshcomp(ver: %s)\n#\n" % __version__)
+        ret.append("_%s()\n{" % self.commandname)
+        ret.append("  local cur\n  local cmd\n\n  cur=${COMP_WORDS[$COMP_CWORD]}")
+        ret.append("  cmd=( ${COMP_WORDS[@]} )\n")
+        if self.parser_type == 'optparse':
+            actions = self.parser.option_list
+        elif self.parser_type == 'argparse':
+            actions = self.parser._actions
+        opts = []
+        for action in actions:
+            if self.parser_type == 'optparse':
+                opts += [i for i in action._long_opts]
+                opts += [i for i in action._short_opts]
+            elif self.parser_type == 'argparse':
+                opts += action.option_strings
+        ret.append("  if [[ \"$cur\" == -* ]]; then")
+        ret.append("    COMPREPLY=( $( compgen -W \"%s\" -- $cur ) )" % " ".join(opts))
+        ret.append("    return 0")
+        ret.append("  fi")
+        ret.append("}\n")
+        ret.append("complete -F _%s -o default %s" % (self.commandname, self.commandname))
+        return "\n".join(ret)
+
     def _get_zsh_format(self):
         """return to string of zsh completion function format."""
         if self.parser_type == 'optparse':
@@ -139,7 +167,12 @@ class ZshCompletionGenerator(object):
         ret.append("_arguments -s -S \\")
         for action in actions:
             if action.metavar:
-                metavar = "::%s:_files" % action.metavar
+                if self.parser_type == 'argparse' and \
+                    action.metavar[0] == '{' and action.metavar[-1] == '}':
+                    metas = action.metavar[1:-1].split(',')
+                    metavar = "::%s:(%s):" % (action.metavar, " ".join(metas))
+                else:
+                    metavar = "::%s:_files" % action.metavar
             else:
                 metavar = ""
             if self.parser_type == 'optparse':
@@ -269,6 +302,7 @@ class HelpParser(object):
         return parser
 
     def help2parseobj(self):
+        """wrapper of help2optparse and help2argparse."""
         if self.parser_type == 'optparse':
             _method = self.help2optparse
         else:
@@ -283,7 +317,6 @@ class HelpParser(object):
         ## 1 is 'Options' line
         for line in self.parselines[1:]:
             if line.isspace() or not len(line) or '--help     ' in line:
-                ## FIXME: judged to '--help     ' is durty hack...
                 continue
             tmp = line.split()
             metavar = None
@@ -356,13 +389,17 @@ class HelpParser(object):
         for line in self.parselines[1:]:
             if line.isspace() or not len(line) or '--help     ' in line or \
                '--version  ' in line:
-                ## FIXME: judged to '--help     ' is durty hack...
                 continue
             tmp = line.split()
             metavar = None
-            if line.find('--') < helpstring_offset and \
+            if (2 <= helpstring_offset or line[2] == '-') and \
                  len(tmp) > 2 and tmp[2][0] == '-':
                 ## (long option and) short option and exist METAVAR
+                if tmp[0][0] != '-':
+                    # invalid
+                    option_list[option_cnt]['help'] += line[helpstring_offset:]
+                    option_list[option_cnt]['help'] += " "
+                    continue
                 optlist = line.split()
                 longopt = optlist[0]
                 shortopt = optlist[2]
@@ -428,7 +465,7 @@ def main():
                            description=__doc__,
                            usage=USAGE_DOCS)
     oparser.add_option("-f", "--output-format", dest="output_format",
-                       help="output format type [zsh|list] (default: zsh)")
+                       help="output format type [zsh|bash|list] (default: zsh)")
     (opts, args) = oparser.parse_args()
     if sys.stdin.isatty() and len(args):
         helptext = open(args[0]).read()
@@ -449,9 +486,9 @@ def main():
     help_parser = HelpParser(helptext)
     command_name = help_parser.get_commandname()
     option_parser = help_parser.help2parseobj()
-    zshop = ZshCompletionGenerator(command_name, option_parser,
-                                   output_format=opts.output_format)
-    print(zshop.get())
+    compobj = CompletionGenerator(command_name, option_parser,
+                                  output_format=opts.output_format)
+    print(compobj.get())
     return 0
 
 
