@@ -80,56 +80,56 @@ class TestReturnDirCompString(TestCase):
     @available_argparse
     def test_argparse_help_short(self):
         parser = argparse.ArgumentParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('-h'))
 
     @available_argparse
     def test_argparse_help_long(self):
         parser = argparse.ArgumentParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('--help'))
 
     @available_argparse
     def test_argparse_version_short(self):
         parser = argparse.ArgumentParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('-v'))
 
     @available_argparse
     def test_argparse_version_long(self):
         parser = argparse.ArgumentParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('--version'))
 
     @available_argparse
     def test_argparse_dirfiles(self):
         parser = argparse.ArgumentParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual('', generator._get_dircomp('-c'))
 
     def test_optparse_help_short(self):
         parser = OptionParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('-h'))
 
     def test_optparse_help_long(self):
         parser = OptionParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual(':', generator._get_dircomp('--help'))
 
     def test_optparse_version_short(self):
         parser = OptionParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual('', generator._get_dircomp('-v'))
 
     def test_optparse_version_long(self):
         parser = OptionParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertNotEqual('::->dirfile', generator._get_dircomp('--version'))
 
     def test_optparse_dirfiles(self):
         parser = OptionParser()
-        generator = genzshcomp.ZshCompletionGenerator('dummy', parser)
+        generator = genzshcomp.CompletionGenerator('dummy', parser)
         self.assertEqual('', generator._get_dircomp('-c'))
 
 
@@ -329,6 +329,44 @@ Options:
         o = oparser.get_option('--notes')
         #self.assertEqual('List', o.help[:4])   # FIXME: not parsing
 
+    @available_argparse
+    def test_boom_help_ver0_4(self):
+        help_string = """\
+usage: boom [-h] [--version] [-m {GET,POST,DELETE,PUT,HEAD,OPTIONS}]
+            [--content-type CONTENT_TYPE] [-D DATA] [-c CONCURRENCY] [-a AUTH]
+            [-n REQUESTS | -d DURATION | -H HEADER]
+            [url]
+
+Simple HTTP Load runner.
+
+positional arguments:
+  url                   URL to hit
+
+optional arguments:
+  -h, --help            show this help message and exit
+  --version             Displays version and exits.
+  -m {GET,POST,DELETE,PUT,HEAD,OPTIONS}, --method {GET,POST,DELETE,PUT,HEAD,OPTIONS}
+                        HTTP Method
+  --content-type CONTENT_TYPE
+                        Content-Type
+  -D DATA, --data DATA  Data. Prefixed by "py:" to point a python callable.
+  -c CONCURRENCY, --concurrency CONCURRENCY
+                        Concurrency
+  -a AUTH, --auth AUTH  Basic authentication user:password
+  -n REQUESTS, --requests REQUESTS
+                        Number of requests
+  -d DURATION, --duration DURATION
+                        Duration in seconds
+  -H HEADER, --header HEADER
+                        Custom header. name:value
+        """
+        hp = genzshcomp.HelpParser(help_string)
+        oparser = hp.help2argparse()
+        args = oparser.parse_args(["--method", "GET"])
+        self.assertEqual(True, "method" in args)
+        args = oparser.parse_args(["-m", "PUT"])
+        self.assertEqual(True, "method" in args)
+
     def test_gunicorn_help_ver0_12(self):
         """test example is gunicorn's(version0.12) help strings"""
         help_string = """\
@@ -429,6 +467,7 @@ Options:
         self.assertEqual(True, oparser.has_option("--help"))
         self.assertEqual(True, oparser.has_option("--version"))
 
+    @available_argparse
     def test_argparse_long_and_short(self):
         """example of httpie"""
         help_string = """
@@ -505,7 +544,7 @@ Options:
         hp = genzshcomp.HelpParser(help_string)
         oparser = hp.help2optparse()
         parser = OptionParser()
-        zshop = genzshcomp.ZshCompletionGenerator('dummy', parser,
+        zshop = genzshcomp.CompletionGenerator('dummy', parser,
                     output_format='list')
         zshlist = zshop.get()
         self.assertEqual(True, '--help:show' in zshlist)
